Crate vcdiff_reader
vcdiff_
reader
1.0.0
All Items
Crate Items
Structs
Enums
Functions
Crate
vcdiff_
reader
Structs

VCDReader
A reader for VCDIFF patches.
Enums

VCDiff
Read
Msg
Represents the main messages that can be emitted by the Reader while processing a VCDIFF patch.
Functions

read_
header
Reads the fixed part of the VCDIFF patch file header.
read_
window_
header
Reads the window header from the VCDIFF patch file. To avoid the Seek trait we require the caller to tell us the current position of the reader. This way the caller can know that the reader can only read exactly the window header.